@@ -1,5 +1,5 @@
 package overload::x;
-use 5.006; use strict; use warnings; our $VERSION = '0.03';
+use 5.006; use strict; use warnings; our $VERSION = '0.10';
 use base 'Import::Export';
 use Function::Fallback::CoreOrPP qw(clone);
 
@@ -17,11 +17,10 @@ sub n {
 
 sub x {
 	my ($times, $obj) = @_;
-	my $o = ref $times;
 	my @times = map {
 		ref $obj ? clone($obj) : $obj
-	} 1 .. ($o ? $$times : $times); # IN list context this counts which suckkks...
-	wantarray && !$o ? @times : \@times;
+	} 1 .. (ref $times ? $$times : $times); # IN list context this counts which suckkks...
+	wantarray ? @times : \@times;
 }
 
 1;
@@ -34,7 +33,7 @@ overload::x - x refs
 
 =head1 VERSION
 
-Version 0.03
+Version 0.10
 
 =cut
 
